cmd

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommitCommand

func NewCommitCommand(a *app.App) *cobra.Command

NewCommitCommand creates the commit command with AI-enhanced commit message support

func NewRootCommand

func NewRootCommand(a *app.App) *cobra.Command

NewRootCommand returns the root cobra.Command.

func NewSetupCommand

func NewSetupCommand() *cobra.Command

NewSetupCommand creates a new command for interactive configuration setup.

func NewStatusCommand

func NewStatusCommand(a *app.App) *cobra.Command

NewStatusCommand creates the status command which shows the working tree status and AI-generated insights regarding the changes.

func RunSetup

func RunSetup() (*config.Config, error)

Types

This section is empty.

Jump to