Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
Config *config.Config
Repo *git.Repository
GitCmd string
}
App holds configuration, repository and the git executable path.
func New ¶
New creates a new App instance by locating the git executable, loading configuration, and opening the git repository (if any).
func (*App) GenerateCommitMessage ¶
GenerateCommitMessage creates a commit message based on the diff and staged file names by calling an AI service.
func (*App) GetStagedFiles ¶
GetStagedFiles retrieves a list of staged file names.
Click to show internal directories.
Click to hide internal directories.