Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommitCommand ¶
NewCommitCommand creates the commit command with AI-enhanced commit message support
func NewRootCommand ¶
NewRootCommand returns the root cobra.Command.
func NewSetupCommand ¶
NewSetupCommand creates a new command for interactive configuration setup.
func NewStatusCommand ¶
NewStatusCommand creates the status command which shows the working tree status and AI-generated insights regarding the changes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.